%CODIFICADOR DEL PITCH.
%function [Nc,bc,dpp]=ltpc(d,dpc)
%Entradas:
%d:señal sin envolvente.
%dpc:120 muestras anteriores reconstruidas.
%Salidas:
%Nc:término de correlación codificado.
%bc:ganancia codificada.
%dpp:pitch de la señal.
function [Nc,bc,dpp]=ltpc(d,dpc)
[N,b]=calcltp(d,dpc);%calculamos los términos LTP.
[Nc,bc]=ltpcod(N,b);%codificamos los términos LTP.
[Np,bp]=ltpdec(Nc,bc);%decodificamos los términos LTP codificados.
dpp=bp*dpc((121-Np):(160-Np));%calculamos el pitch de la señal.

